==> igniteui-react-charts-18.0.0.tgz: package/esm5/lib/igr-callout-label-updating-event-args.js <==
import { IgrSeries } from "./igr-series";
import { CalloutLabelUpdatingEventArgs as CalloutLabelUpdatingEventArgs_internal } from "./CalloutLabelUpdatingEventArgs";
/**
 * Represents event arguments for updating label of callout layer
*/
var IgrCalloutLabelUpdatingEventArgs = /** @class */ /*@__PURE__*/ (function () {
    function IgrCalloutLabelUpdatingEventArgs() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    IgrCalloutLabelUpdatingEventArgs.prototype.createImplementation = function () {
        return new CalloutLabelUpdatingEventArgs_internal();
    };
    Object.defineProperty(IgrCalloutLabelUpdatingEventArgs.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrCalloutLabelUpdatingEventArgs.prototype.onImplementationCreated = function () {
    };
    IgrCalloutLabelUpdatingEventArgs.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    };
    Object.defineProperty(IgrCalloutLabelUpdatingEventArgs.prototype, "xValue", {
        /**
         * Gets data X-value assositated with callout layer
        */
        get: function () {
            return this.i.d;
        },
        set: function (v) {
            this.i.d = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrCalloutLabelUpdatingEventArgs.prototype, "yValue", {
        /**
         * Gets data Y-value assositated with callout layer
        */
        get: function () {
            return this.i.e;
        },
        set: function (v) {
            this.i.e = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrCalloutLabelUpdatingEventArgs.prototype, "item", {
        /**
         * Gets data item assositated with callout layer
        */
        get: function () {
            return this.i.item;
        },
        set: function (v) {
            this.i.item = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrCalloutLabelUpdatingEventArgs.prototype, "series", {
        /**
         * Gets series assositated with callout item, if available
        */
        get: function () {
            if (this.i.a == null) {
                return null;
            }
            if (!this.i.a.externalObject) {
                var e = IgrSeries._createFromInternal(this.i.a);
                if (e) {
                    e._implementation = this.i.a;
                }
                this.i.a.externalObject = e;
            }
            return this.i.a.externalObject;
        },
        set: function (v) {
            v == null ? this.i.a = null : this.i.a = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrCalloutLabelUpdatingEventArgs.prototype, "seriesName", {
        /**
         * Gets series name assositated with callout item, if available
        */
        get: function () {
            return this.i.f;
        },
        set: function (v) {
            this.i.f = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrCalloutLabelUpdatingEventArgs.prototype, "label", {
        /**
         * Gets or sets label displayed by callout layer
        */
        get: function () {
            return this.i.c;
        },
        set: function (v) {
            this.i.c = v;
        },
        enumerable: false,
        configurable: true
    });
    return IgrCalloutLabelUpdatingEventArgs;
}());
export { IgrCalloutLabelUpdatingEventArgs };

==> igniteui-react-charts-18.1.0.tgz: package/esm5/lib/igr-callout-label-updating-event-args.js <==
import { IgrSeries } from "./igr-series";
import { CalloutLabelUpdatingEventArgs as CalloutLabelUpdatingEventArgs_internal } from "./CalloutLabelUpdatingEventArgs";
/**
 * Represents event arguments for updating label of callout layer
*/
var IgrCalloutLabelUpdatingEventArgs = /** @class */ /*@__PURE__*/ (function () {
    function IgrCalloutLabelUpdatingEventArgs() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    IgrCalloutLabelUpdatingEventArgs.prototype.createImplementation = function () {
        return new CalloutLabelUpdatingEventArgs_internal();
    };
    Object.defineProperty(IgrCalloutLabelUpdatingEventArgs.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrCalloutLabelUpdatingEventArgs.prototype.onImplementationCreated = function () {
    };
    IgrCalloutLabelUpdatingEventArgs.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    };
    Object.defineProperty(IgrCalloutLabelUpdatingEventArgs.prototype, "xValue", {
        /**
         * Gets data X-value assositated with callout layer
        */
        get: function () {
            return this.i.d;
        },
        set: function (v) {
            this.i.d = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrCalloutLabelUpdatingEventArgs.prototype, "yValue", {
        /**
         * Gets data Y-value assositated with callout layer
        */
        get: function () {
            return this.i.e;
        },
        set: function (v) {
            this.i.e = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrCalloutLabelUpdatingEventArgs.prototype, "item", {
        /**
         * Gets data item assositated with callout layer
        */
        get: function () {
            return this.i.item;
        },
        set: function (v) {
            this.i.item = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrCalloutLabelUpdatingEventArgs.prototype, "series", {
        /**
         * Gets series assositated with callout item, if available
        */
        get: function () {
            var r = this.i.a;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = IgrSeries._createFromInternal(r);
                if (e) {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            v == null ? this.i.a = null : this.i.a = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrCalloutLabelUpdatingEventArgs.prototype, "seriesName", {
        /**
         * Gets series name assositated with callout item, if available
        */
        get: function () {
            return this.i.f;
        },
        set: function (v) {
            this.i.f = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrCalloutLabelUpdatingEventArgs.prototype, "label", {
        /**
         * Gets or sets label displayed by callout layer
        */
        get: function () {
            return this.i.c;
        },
        set: function (v) {
            this.i.c = v;
        },
        enumerable: false,
        configurable: true
    });
    return IgrCalloutLabelUpdatingEventArgs;
}());
export { IgrCalloutLabelUpdatingEventArgs };
